@@ -11,10 +11,10 @@
 
 plostitle <- function(q = NULL, fl = 'id', fq = NULL, sort = NULL,
   start = 0, limit = 10, sleep = 6, errors = "simple", proxy = NULL,
-  callopts=NULL, ...) {
+  callopts=NULL, progress = NULL, ...) {
 
   searchplos(q=paste('title:', '"', q, '"', sep=""), fl=fl, fq=fq,
              sort=sort, start=start, limit=limit,
              sleep=sleep, errors = errors,
-             proxy = proxy, callopts = callopts, ...)
+             proxy = proxy, callopts = callopts, progress = progress, ...)
 }
